@@ -276,16 +276,31 @@ class Laplacian(Discretizer):
                         continue
 
                     if bc.bc_type == "neumann" or bc.bc_type == "symmetry":
+                        # Treatment for the cylindrical coordinate
+                        dr = var.mesh.dx[j] if j == 0 else 0.0
+                        r = (
+                            var.mesh.grid[j][bc.bc_mask_prev]
+                            if j == 0
+                            else torch.zeros_like(var.mesh.grid[j][bc.bc_mask_prev])
+                        )
+                        alpha = (
+                            torch.nan_to_num(
+                                4 / 3 * dr / r, nan=0.0, posinf=0.0, neginf=0.0
+                            )
+                            if var.mesh.coord_sys == "rz"
+                            else torch.zeros_like(r)
+                        )
+
                         if bc.bc_n_dir < 0:
                             # At lower side
-                            Ap[j][i][bc.bc_mask_prev] = 2 / 3
-                            Ac[j][i][bc.bc_mask_prev] = -2 / 3
+                            Ap[j][i][bc.bc_mask_prev] = 2 / 3 + alpha
+                            Ac[j][i][bc.bc_mask_prev] = -(2 / 3 + alpha)
                             Am[j][i][bc.bc_mask_prev] = 0.0
                         else:
                             # At upper side
                             Ap[j][i][bc.bc_mask_prev] = 0.0
-                            Ac[j][i][bc.bc_mask_prev] = -2 / 3
-                            Am[j][i][bc.bc_mask_prev] = 2 / 3
+                            Ac[j][i][bc.bc_mask_prev] = -(2 / 3 + alpha)
+                            Am[j][i][bc.bc_mask_prev] = 2 / 3 + alpha
                     else:
                         # Do nothing
                         pass
@@ -310,9 +325,24 @@ class Laplacian(Discretizer):
             for j in range(var.mesh.dim):
                 for bc in var.bcs:
                     if bc.bc_type == "neumann":
+                        # Treatment for the cylindrical coordinate
+                        dr = var.mesh.dx[j] if j == 0 else 0.0
+                        r = (
+                            var.mesh.grid[j][bc.bc_mask_prev]
+                            if j == 0
+                            else torch.zeros_like(var.mesh.grid[j][bc.bc_mask_prev])
+                        )
+                        alpha = (
+                            torch.nan_to_num(
+                                2 / 3 * dr / r, nan=0.0, posinf=0.0, neginf=0.0
+                            )
+                            if var.mesh.coord_sys == "rz"
+                            else torch.zeros_like(r)
+                        )
+
                         at_bc = _return_bc_val(bc, var, i)
                         rhs_adj[i][bc.bc_mask_prev] += (
-                            (2 / 3) * (at_bc * bc.bc_n_vec[j]) / dx[j]
+                            (2 / 3 - alpha) * (at_bc * bc.bc_n_vec[j]) / dx[j]
                         )
                     else:
                         # Do nothing
